@@ -242,9 +242,15 @@ procview_new (GTopProcViewData *d, GtkWidget *widget, gint ftype)
 
 	procview_clist_prepare (d);
 
+	gtk_widget_ensure_style (d->clist);
 	style = gtk_style_copy (gtk_widget_get_style (d->clist));
+
+	gdk_font_unref (style->font);
 	style->font = gtop_properties.procview.font;
+	gdk_font_ref (style->font);
+
 	gtk_widget_set_style (d->clist, style);
+	gtk_style_unref (style);
 
 	procview_click_column (GTK_CLIST (d->clist), config_sort_field, d);
 	
@@ -649,9 +655,15 @@ procview_clist_prepare (GTopProcViewData *d)
 
 		gtk_label_set (GTK_LABEL (bc->widget), _(CF->label));
 
+		gtk_widget_ensure_style (bc->widget);
 		style = gtk_style_copy (gtk_widget_get_style (bc->widget));
+
+		gdk_font_unref (style->font);
 		style->font = gtop_properties.procview.font;
+		gdk_font_ref (style->font);
+
 		gtk_widget_set_style (bc->widget, style);
+		gtk_style_unref (style);
 
 		CF->hb = hb;
 		c = c->next;
@@ -1107,9 +1119,15 @@ procview_properties_update (GnomePropertyObject *object)
 		GTopProcViewData *d = &procview->data;
 		GtkStyle *style;
 
+		gtk_widget_ensure_style (d->clist);
 		style = gtk_style_copy (gtk_widget_get_style (d->clist));
+
+		gdk_font_unref (style->font);
 		style->font = gtop_properties.procview.font;
+		gdk_font_ref (style->font);
+
 		gtk_widget_set_style (d->clist, style);
+		gtk_style_unref (style);
 
 		procview_update (&procview->data);
 	}
