@@ -2,11 +2,7 @@
 #ifndef __PROCVIEW_H__
 #define __PROCVIEW_H__
 
-#include <properties.h>
-
-#include <graph.h>
-
-#include <proc.h>
+#include <summary.h>
 
 typedef struct	_GTopProcViewData	GTopProcViewData;
 typedef enum	_GTopProcViewType	GTopProcViewType;
@@ -61,36 +57,16 @@ struct _GTopProcViewData
 {
 	GTopProcViewType	ftype;
 	GTopProcViewDetails	details;
+	GTopSummaryData		*summary_data;
 	gulong			proc_selection_flags;
 	GtkWidget		*renice_dialog, *renice_msg;
 	GtkAdjustment		*renice_adj;
 	GtkWidget		*bin, *vbox, *sw, *clist, *clist_menu;
-	GtkWidget		*summary, *summary_box;
-	GtkWidget		*summary_cpu, *summary_mem, *summary_swap;
-	GtkWidget		*summary_load;
-#ifdef HAVE_LIBGTOP_SMP
-	GtkWidget		*summary_xcpu [4];
-#endif
-	ProcInfo		*summary_info;
-	GtkWidget		*statusbar;
-	GtkWidget		*status_host, *status_host_label;
-	GtkWidget		*status_cpu, *status_cpu_label;
-	GtkWidget		*status_mem, *status_mem_label;
-	GtkWidget		*status_uptime, *status_uptime_label;
-	GtkWidget		*status_loadavg, *status_loadavg_label;
-	guint			status_cpu_timeout;
-	guint			status_mem_timeout;
-	guint			status_uptime_timeout;
-	guint			status_loadavg_timeout;
 	gint			select_pid;
 	unsigned		*proc_tab;
 	int			prev_count;
 	GList			*field_list, *geometry_list;
 	gint			field_list_length;
-	GtkWidget		*xpm_cpu, *xpm_mem, *xpm_swap, *xpm_load;
-#ifdef HAVE_LIBGTOP_SMP
-	GtkWidget		*xpm_xcpu [4];
-#endif
 	GtkWidget		*sort_asc, *sort_dsc;
 	int			sort_field, sort_order;
 	GTopProcField		*p_fields;
@@ -188,6 +164,7 @@ struct _GTopProcField {
 
 extern GnomePropertyDescriptor ProcViewProperty_Descriptor;
 extern GnomePropertyDescriptor ProcFieldsProperty_Descriptor;
+extern GnomePropertyDescriptor SummaryProperty_Descriptor;
 extern GnomePropertyDescriptor SummaryColorsProperty_Descriptor;
 
 extern GTopProcField gtop_proc_fields [];
