@@ -86,6 +86,7 @@ static void summary_properties_apply (GnomePropertyObject *object);
 static void summary_properties_update (GnomePropertyObject *object);
 static void summary_properties_load (GnomePropertyObject *object);
 static void summary_properties_save (GnomePropertyObject *object);
+static void summary_properties_changed (GnomePropertyObject *object);
 
 static GtkWidget *summary_colors_properties_init (GnomePropertyObject *object);
 static void summary_colors_properties_update (GnomePropertyObject *object);
@@ -111,7 +112,9 @@ GnomePropertyDescriptor SummaryProperty_Descriptor = {
 	summary_properties_update,
 	summary_properties_load,
 	summary_properties_save,
-	NULL, NULL, NULL, NULL, NULL
+	NULL, NULL, NULL,
+	summary_properties_changed,
+	NULL
 };
 
 static GList *statusbar_object_list = NULL;
@@ -558,10 +561,15 @@ gtop_statusbar_new (void)
 		(GTK_CONTAINER (d->container), GNOME_PAD_SMALL);
 
 	style = gtk_style_copy (gtk_widget_get_style (d->container));
+
+	gdk_font_unref (style->font);
 	style->font = gtop_properties.summary.statusbar_font;
+	gdk_font_ref (style->font);
+
 	gtk_widget_push_style (style);
 	
-	d->status_bar = gnome_appbar_new (FALSE, TRUE, GNOME_PREFERENCES_NEVER);
+	d->status_bar = gnome_appbar_new
+		(FALSE, TRUE, GNOME_PREFERENCES_NEVER);
 
 	gtk_box_pack_start
 		(GTK_BOX (d->container), d->status_bar, TRUE, TRUE, 0);
@@ -623,6 +631,7 @@ gtop_statusbar_new (void)
 		(GTK_BOX (d->container), d->status_loadavg, FALSE, FALSE, 0);
 
 	gtk_widget_pop_style ();
+	gtk_style_unref (style);
 
 	statusbar_object_list = g_list_append (statusbar_object_list, d);
 
@@ -784,6 +793,24 @@ adjustment_changed_cb (GtkWidget *widget,
 	gtop_properties_changed ();
 }
 
+static void
+update_font (GtkWidget *widget)
+{
+	GtkStyle *style;
+
+	if (!widget) return;
+
+	gtk_widget_ensure_style (widget);
+	style = gtk_style_copy (gtk_widget_get_style (widget));
+
+	gdk_font_unref (style->font);
+	style->font = gtop_properties.summary.statusbar_font;
+	gdk_font_ref (style->font);
+
+	gtk_widget_set_style (widget, style);
+	gtk_style_unref (style);
+}
+
 static void
 summary_properties_update (GnomePropertyObject *object)
 {
@@ -792,6 +819,11 @@ summary_properties_update (GnomePropertyObject *object)
 	for (c = statusbar_object_list; c; c = c->next) {
 		GTopStatusBarData *d = c->data;
 
+		update_font (d->status_cpu_label);
+		update_font (d->status_mem_label);
+		update_font (d->status_uptime_label);
+		update_font (d->status_loadavg_label);
+
 		gtop_statusbar_update (d);
 	}
 }
